import { Packager, DeployMode } from './Packager';
import { ZipBuilder } from './ZipBuilder';
import { S3Ref } from './S3Ref';
import { BigbandModel } from './models/BigbandModel';
import { SectionModel } from './models/SectionModel';
import { InstrumentModel } from './models/InstrumentModel';
export { DeployMode } from './Packager';
export interface PushedInstrument {
    s3Ref: S3Ref;
    wasPushed: boolean;
    existed: boolean;
    physicalName: string;
    model: InstrumentModel;
}
export declare class BigbandFileRunner {
    private readonly bigbandModel;
    private readonly sectionModel;
    private readonly teleportingEnabled;
    private readonly deployMode;
    private readonly awsFactory;
    private readonly poolPrefix;
    private readonly blobPool;
    private readonly teleportInstrument;
    private readonly namer;
    constructor(bigbandModel: BigbandModel, sectionModel: SectionModel, teleportingEnabled: boolean, deployMode: DeployMode);
    private readonly s3Bucket;
    static runBigbandFile(bigbandFile: string, pathToSection: string, teleportingEnabled: boolean, deployMode: DeployMode): Promise<string>;
    private runSpec;
    buildCloudFormationTemplate(pushedInstruments: PushedInstrument[]): {
        AWSTemplateFormatVersion: string;
        Transform: string;
        Description: string;
        Resources: {};
    };
    private pushCode;
    compileInstrument(d: string, npmPackageDir: string, instrumentModel: InstrumentModel): Promise<{
        zb: ZipBuilder;
        packager: Packager;
    }>;
    private ttlPrefix;
    private createBucketIfNeeded;
    private configureBucket;
    static loadModel(bigbandFile: string): Promise<BigbandModel>;
}
