import { BigbandSpec, Instrument, Section, Bigband, NavigationItem } from "bigband-core";
import { SectionModel } from "./SectionModel";
import { InstrumentModel } from "./InstrumentModel";
export interface AssignedInstrument {
    instrument: Instrument;
    section: Section;
}
export interface LookupResult {
    section: Section;
    sectionModel: SectionModel;
    instrumentModel: InstrumentModel;
    instrument: Instrument;
    physicalName: string;
}
export interface InsepctResult {
    list: NavigationItem[];
    data?: any;
}
export declare class BigbandModel {
    private readonly spec;
    readonly accountId: string;
    private readonly sectionByPath;
    private readonly instrumentModelByPath;
    readonly dir: string;
    constructor(spec: BigbandSpec, defaultDir: string, accountId?: string);
    readonly bigband: Bigband;
    readonly profileName: string;
    /**
     * Fetches an instrument by its full path. Throws an exception if not found.
     *
     * @param {string} path
     * @returns {InstrumentModel}
     */
    getInstrument(path: string): InstrumentModel;
    findSectionModel(path: string): SectionModel;
    private readonly sections;
    private readonly instruments;
    inspect(path_: string, includeSynthetic?: boolean): Promise<InsepctResult>;
    searchInspect(path: string): Promise<LookupResult>;
    validate(): void;
}
